@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -89,6 +89,30 @@ struct length_impl
     value_type operator()(value_type const& val) const { return val.to_unicode().length(); }
 };
 
+// str
+struct str_impl
+{
+    value_type operator()(value_type const& val) const { return val.to_unicode(); }
+};
+
+// bool
+struct bool_impl
+{
+    value_type operator()(value_type const& val) const { return val.to_bool(); }
+};
+
+// int
+struct int_impl
+{
+    value_type operator()(value_type const& val) const { return val.to_int(); }
+};
+
+// float
+struct float_impl
+{
+    value_type operator()(value_type const& val) const { return val.to_double(); }
+};
+
 // min
 inline value_type min_impl(value_type const& arg1, value_type const& arg2)
 {
