@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,8 +49,8 @@ class path_iterator : public boost::iterator_facade<path_iterator<T>,
     using value_type = typename std::tuple<unsigned, double, double>;
 
     path_iterator()
-        : v_(mapnik::SEG_END, 0, 0)
-        , vertices_()
+        : v_(mapnik::SEG_END, 0, 0),
+          vertices_()
     {}
 
     explicit path_iterator(path_type const& vertices)
@@ -70,7 +70,7 @@ class path_iterator : public boost::iterator_facade<path_iterator<T>,
     value_type const& dereference() const { return v_; }
 
     value_type v_;
-    const path_type* vertices_;
+    path_type const* vertices_;
 };
 
 // specialization for mapnik::path_type - vertex interface has been removed
@@ -84,14 +84,14 @@ class path_iterator<path_type> : public boost::iterator_facade<path_iterator<pat
     using value_type = std::tuple<unsigned, double, double>;
     using size_type = path_type::size_type;
     path_iterator()
-        : v_(mapnik::SEG_END, 0, 0)
-        , vertices_()
-        , pos_(0)
+        : v_(mapnik::SEG_END, 0, 0),
+          vertices_(),
+          pos_(0)
     {}
 
     explicit path_iterator(path_type const& vertices)
-        : vertices_(&vertices)
-        , pos_(0)
+        : vertices_(&vertices),
+          pos_(0)
     {
         increment();
     }
@@ -110,7 +110,7 @@ class path_iterator<path_type> : public boost::iterator_facade<path_iterator<pat
     value_type const& dereference() const { return v_; }
 
     value_type v_;
-    const path_type* vertices_;
+    path_type const* vertices_;
     size_type pos_;
 };
 
