@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,13 +33,13 @@ namespace mapnik {
 class view_transform
 {
   private:
-    const int width_;
-    const int height_;
-    const box2d<double> extent_;
-    const double sx_;
-    const double sy_;
-    const double offset_x_;
-    const double offset_y_;
+    int const width_;
+    int const height_;
+    box2d<double> const extent_;
+    double const sx_;
+    double const sy_;
+    double const offset_x_;
+    double const offset_y_;
     int offset_;
 
   public:
@@ -49,14 +49,14 @@ class view_transform
                    box2d<double> const& _extent,
                    double _offset_x = 0.0,
                    double _offset_y = 0.0)
-        : width_(_width)
-        , height_(_height)
-        , extent_(_extent)
-        , sx_(extent_.width() > 0 ? static_cast<double>(width_) / extent_.width() : 1.0)
-        , sy_(extent_.height() > 0 ? static_cast<double>(height_) / extent_.height() : 1.0)
-        , offset_x_(_offset_x)
-        , offset_y_(_offset_y)
-        , offset_(0)
+        : width_(_width),
+          height_(_height),
+          extent_(_extent),
+          sx_(extent_.width() > 0 ? static_cast<double>(width_) / extent_.width() : 1.0),
+          sy_(extent_.height() > 0 ? static_cast<double>(height_) / extent_.height() : 1.0),
+          offset_x_(_offset_x),
+          offset_y_(_offset_y),
+          offset_(0)
     {}
 
     view_transform(view_transform const&) = default;
